-- Create a Frame to handle all in coming events.
local watcher = CreateFrame("Frame","Watchtower",UIParent);
watcher:SetPoint("TOPLEFT");
watcher:Hide();
watcher:RegisterAllEvents();
-- Event handler
watcher:SetScript("OnEvent", function(self, event)
	if event == "GARRISON_MISSION_NPC_OPENED" then
		-- Creates the watchtower tab when mission table is opened.
		init_traits();
		Create_Watchtower_Tab();
	elseif event == "GARRISON_MISSION_NPC_CLOSED" then
		-- Deselects the watchtower tab.
		PanelTemplates_DeselectTab(GarrisonMissionFrameTab5);
		-- Hides the watchtower main UI if it exists and is visible.
		if watchtower_main_ui ~= nil and watchtower_main_ui.isShown then
			watchtower_main_ui:Hide();
		end
	end
end);

function Create_Watchtower_Tab()
	-- If the tab doesn't exist then create it. 
	if GarrisonMissionFrameTab5 == nil then
		CreateFrame("Button", "GarrisonMissionFrameTab5", GarrisonMissionFrame, "GarrisonMissionFrameTabTemplate");
		GarrisonMissionFrameTab5:SetPoint("LEFT", GarrisonMissionFrameTab2, "RIGHT", -5, 0);
		PanelTemplates_DeselectTab(GarrisonMissionFrameTab5);
		GarrisonMissionFrameTab5:SetText("Watchtower");
		PanelTemplates_TabResize(GarrisonMissionFrameTab5, 10);
		local MP_L = GarrisonMissionFrameTab4;
		GarrisonMissionFrameTab1:HookScript("OnClick", function()
			PanelTemplates_DeselectTab(GarrisonMissionFrameTab5);
			if watchtower_main_ui ~= nil then
				watchtower_main_ui:Hide();
			end
		end)
		GarrisonMissionFrameTab2:HookScript("OnClick", function()
			PanelTemplates_DeselectTab(GarrisonMissionFrameTab5);
			if watchtower_main_ui ~= nil then
				watchtower_main_ui:Hide();
			end
		end)
		if MP_L ~= nil then
			GarrisonMissionFrameTab3:HookScript("OnClick", function()
				PanelTemplates_DeselectTab(GarrisonMissionFrameTab5);
				if watchtower_main_ui ~= nil then
					watchtower_main_ui:Hide();
				end
			end)
			GarrisonMissionFrameTab4:HookScript("OnClick", function()
				PanelTemplates_DeselectTab(GarrisonMissionFrameTab5);
				if watchtower_main_ui ~= nil then
					watchtower_main_ui:Hide();
				end
			end)
		end
		GarrisonMissionFrameTab5:SetScript("OnClick", function()
			PanelTemplates_DeselectTab(GarrisonMissionFrameTab1);
			PanelTemplates_DeselectTab(GarrisonMissionFrameTab2);
			if MP_L ~= nil  then
				PanelTemplates_DeselectTab(GarrisonMissionFrameTab3);
				PanelTemplates_DeselectTab(GarrisonMissionFrameTab4);
			end
			PanelTemplates_SelectTab(GarrisonMissionFrameTab5);
			Create_Watchtower_UI();
			Update_Follower_graphs();
		end);
		PanelTemplates_DeselectTab(GarrisonMissionFrameTab5);
		
	end
end

-- Creates the visible UI window.
function Create_Watchtower_UI()
	if watchtower_main_ui == nil then
		local x, y = GarrisonMissionFrame:GetSize();
		x = x * 1.2;
		-- Base Frame
		CreateFrame("Frame", "watchtower_main_ui", UIParent, "GarrisonUITemplate");
		watchtower_main_ui:SetPoint("BOTTOM", GarrisonMissionFrame, "BOTTOM");
		watchtower_main_ui:SetSize(x, y);
		watchtower_main_ui:Hide();
		watchtower_main_ui:SetFrameStrata("HIGH");
		watchtower_main_ui:EnableMouse(true);
		-- Header
		watchtower_main_ui:CreateFontString("Title","ARTWORK" ,"GameFontNormal");
		Title:SetText("Watchtower Version 0.1a");
		Title:SetPoint("TOP", 0, -5);
		-- Footer
		watchtower_main_ui:CreateFontString("Footer", "ARTWORK", "GameFontNormalSmall");
		Footer:SetText("Lot20Syndicate");
		Footer:SetPoint("BOTTOMRIGHT", -50, 5);
		-- Grey inset box
		CreateFrame("Frame", "watchtower_main_ui_greybox", watchtower_main_ui, "GarrisonMissionBaseFrameTemplate");
		watchtower_main_ui_greybox:SetPoint("CENTER");
		watchtower_main_ui_greybox:SetSize((x*0.92), (y * 0.88));
		create_display_boxes();
	end
	watchtower_main_ui:Show();
end

-- Creates all of the graph display boxes -- 
function create_display_boxes()
	local backdrop = {bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background", tile = true, tileSize = 32};
	
	for a = 1, #dbox do
		frame = CreateFrame("Frame", dbox[a].name, watchtower_main_ui_greybox);
		frame:SetBackdrop(backdrop);
		frame:SetSize(dbox[a].x, dbox[a].y);
		frame:SetPoint(dbox[a].self_anchor, dbox[a].relativeto, dbox[a].parent_anchor, dbox[a].x_offset, dbox[a].y_offset);
		local title = frame:CreateFontString(nil, "ARTWORK", "QuestFont_Large");
		title:SetText("|cffffff00" .. dbox[a].title .. "|r");
		title:SetPoint("TOP", 0, -2);
			-- Creates the graph lines
		for b = -9,9 do
			local line = frame:CreateTexture(nil);
			line:SetTexture(1.0, 1.0, 1.0, 0.1);
			line:SetSize((dbox[a].x - 50),1);
			line:SetPoint("CENTER", 0, (b * 9));
			local numleft = frame:CreateFontString(nil,"ARTWORK" ,"GameFontNormalSmall");
			local numright = frame:CreateFontString(nil,"ARTWORK" ,"GameFontNormalSmall");
			numleft:SetPoint("LEFT", line, "RIGHT", 5, 0);
			numright:SetPoint("RIGHT", line, "LEFT",-5, 0);
			if b < 0 then
				numleft:SetText(b * (-1));
				numright:SetText(b * (-1));
			else
				numleft:SetText(b);
				numright:SetText(b);
			end
		end
	end
			-- Creates the icons on each box
	for c = 1, #f_traits do
		local icon = frame:CreateTexture(f_traits[c].name);
		icon:SetTexture(f_traits[c].icon);
		icon:SetSize(24,24);
		icon:SetPoint(f_traits[c].self_anchor, f_traits[c].relativeto, f_traits[c].parent_anchor, f_traits[c].x_offset, f_traits[c].y_offset);
		local active = frame:CreateTexture(f_traits[c].name .. "_active");
		table.insert(f_textures_active, active);
		local inactive = frame:CreateTexture(f_traits[c].name .. "_inactive");
		table.insert(f_textures_inactive, inactive);
		active:SetTexture(0.0,0.8,0.0,0.3);
		active:SetSize(24,9);
		inactive:SetTexture(0.8,0.0,0.0,0.3);
		inactive:SetSize(16,9);
		if f_traits[c].prime then
			active:SetPoint("BOTTOMLEFT", f_traits[c].relativeto, "LEFT", f_traits[c].x_offset, 1);
		else
			active:SetPoint("BOTTOMLEFT", f_traits[c - 1].name .. "_active", "BOTTOMRIGHT", f_traits[c].x_offset, 0);
		end
		inactive:SetPoint("TOP", f_traits[c].name .."_active" , "BOTTOM", 0, -1);
		
	end	
	
end


function Update_Follower_graphs()
	init_traits();
	local myFollowers = {};
	local allFollowers = C_Garrison.GetFollowers();
	for a = 1, #allFollowers do
		if allFollowers[a].isCollected then
			table.insert(myFollowers, allFollowers[a]);
		end
	end
	for b = 1, #f_traits do
		for c = 1, #myFollowers do
			status = myFollowers[c].status;
			follower_abilities = C_Garrison.GetFollowerAbilities(myFollowers[c].followerID);
			for d = 1, #follower_abilities do
				ability = follower_abilities[d];
				if ability.isTrait then
					if ability.name == f_traits[b].name then
						if status == "Inactive" then
							f_traits[b].inactive = f_traits[b].inactive +1;
						else
							f_traits[b].active = f_traits[b].active +1;
						end
					end
				else
					for key, value in pairs(ability.counters) do
						if value.name == f_traits[b].name then
							if status == "Inactive" then
								f_traits[b].inactive = f_traits[b].inactive +1;
							else
								f_traits[b].active = f_traits[b].active +1;
							end
						end
					end
				end
			end
		end
	end
	
	for e = 1, #f_traits do
		if f_traits[e].active == 0 then
			f_textures_active[e]:SetTexture(0.0,0.8,0.0,0.0);
		else
			f_textures_active[e]:SetSize(24,(f_traits[e].active * 9));
		end
		if f_traits[e].inactive == 0 then
			f_textures_inactive[e]:SetTexture(0.0,0.8,0.0,0.0);
		else
			f_textures_inactive[e]:SetSize(16,(f_traits[e].inactive * 9));
		end
	end
end



	







